#
# spec file for package python-oslo.context
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test
Name:           python-oslo.context
Version:        5.6.0
Release:        1.1
Summary:        OpenStack Oslo context library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.context
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.context/oslo.context-5.6.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-pbr >= 2.0.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  python3-debtcollector >= 1.2.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-oslotest
BuildRequires:  python3-stestr
%endif

%description
The Oslo context library has helpers to maintain useful information
about a request context.
The request context is usually populated in the WSGI pipeline and
used by various modules such as logging.

%package -n python3-oslo.context
Summary:        OpenStack Oslo context library
Requires:       python3-debtcollector >= 1.2.0

%description -n python3-oslo.context
The Oslo context library has helpers to maintain useful information
about a request context.
The request context is usually populated in the WSGI pipeline and
used by various modules such as logging.

This package contains the Python 3.x module.

%package -n python-oslo.context-doc
Summary:        Documentation for OpenStack common context library
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-oslo.context-doc
Documentation for the oslo-context library.

%prep
%autosetup -p1 -n oslo.context-5.6.0
%py_req_cleanup

%build
%{py3_build}
# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%if %{with test}
%check
%{openstack_stestr_run}
%endif

%files -n python3-oslo.context
%license LICENSE
%doc README.rst
%{python3_sitelib}/oslo_context
%{python3_sitelib}/*.egg-info

%files -n python-oslo.context-doc
%license LICENSE
%doc doc/build/html

%changelog
* Mon Sep  2 2024 cloud-devel@suse.de
- update to version 5.6.0
  - pre-commit: Remove outdated comment
  - reno: Update master for unmaintained/xena
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/victoria
  - reno: Update master for unmaintained/zed
  - Remove old excludes
  - reno: Update master for unmaintained/wallaby
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 5.5.0
  - Add is_admin to redacted context
  - Update python classifier in setup.cfg
  - pre-commit: Bump dependencies
  - reno: Update master for unmaintained/yoga
  - tox: Drop envdir
  - pre-commit: Integrate bandit, mypy
  - Bump hacking
* Thu Dec 28 2023 cloud-devel@suse.de
- update to version 5.3.0
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Moves supported python runtimes from version 3.8 to 3.10
  - Update master for stable/2023.2
  - Bump bandit
  - Update master for stable/2023.1
  - Add method for getting redacted copy of context
* Wed May  3 2023 cloud-devel@suse.de
- update to version 5.1.1
  - Update master for stable/zed
  - Cleanup py27 support
  - Add Python3 antelope unit tests
  - Fix the docs job
* Tue Aug 16 2022 cloud-devel@suse.de
- update to version 5.0.0
  - Add Python3 zed unit tests
  - Drop python3.6/3.7 support in testing runtime
  - Update master for stable/yoga
  - Remove unnecessary unicode prefixes
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 4.1.0
  - Don't test with setuptools local distutils.
  - Remove the deprecated argument tenant from RequestContext
  - Update master for stable/xena
  - Integrate mypy
  - Add Python3 yoga unit tests
  - Fix context from_dict() for system_scope
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 3.3.1
  - Drop use of deprecated collections classes
  - Add Python3 xena unit tests
  - setup.cfg: Replace dashes with underscores
  - Remove lower-constraints remnants
  - Use TOX_CONSTRAINTS_FILE
  - Fix formatting of release list
  - Use py3 as the default runtime for tox
  - Ussuri+ is python3 only and update python to python3
  - Update master for stable/wallaby
  - Move flake8 as a pre-commit local target.
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.2.0
  - Switch to collections.abc.MutableMapping
  - Adding pre-commit
  - Dropping lower constraints testing
  - Add Python3 wallaby unit tests
  - Update master for stable/victoria
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.1.1
  - Remove translation sections from setup.cfg
  - Switch to newer openstackdocstheme and reno versions
  - Add py38 package metadata
  - Remove the unused coding style modules
  - Update master for stable/ussuri
  - drop mock from lower-constraints
  - Add release notes links to doc index
  - Align contributing doc with oslo's policy
  - Fix hacking min version to 3.0.1
  - Bump bandit version
  - Bump default tox env from py37 to py38
  - Add Python3 victoria unit tests
  - Fix pygments style
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.0.2
  - tox: Stop using 'python setup.py test'
  - tox: Keeping going with docs
  - Drop python 2.7 support and testing
  - Don't build universal wheel
  - Bump the openstackdocstheme extension to 1.20
  - Update master for stable/train
  - tox: Trivial cleanup
  - reword releasenote for py27 support dropping
  - remove outdated header
  - gitignore: Hide reno cache files
  - Filter out auth_token_info from logging values
  - Update the constraints url
  - Update hacking for Python3
  - Switch to Ussuri jobs
  - trivial: Cleanup tox.ini
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 2.23.0
  - Replace git.openstack.org URLs with opendev.org URLs
  - Update master for stable/stein
  - Dropping the py35 testing
  - Add Python 3 Train unit tests
  - OpenDev Migration Patch
  - Cap Bandit below 1.6.0 and update Sphinx requirement
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.22.1
  - Update mailinglist from dev to discuss
  - fix tox python3 overrides
  - Implement domain-scope for context objects
  - Switch to stestr
  - Update hacking version
  - Always build universal wheels
  - Update reno for stable/rocky
  - Clean up .gitignore references to personal tools
  - Add release notes link to README
  - Use template for lower-constraints
  - add lib-forward-testing-python3 test job
  - add python 3.6 unit test job
  - add python 3.7 unit test job
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 2.21.0
  - Remove stale pip-missing-reqs tox test
  - Update reno for stable/queens
  - Update links in README
  - Trivial: Update pypi url to new url
  - Implement system-scope
  - pypy not checked at gate
  - Add -W for document build
  - Switch pep8 job to python 3
  - Updated from global requirements
  - add lower-constraints job
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 2.20.0
  - Remove -U from pip install
  - Follow the new PTI for document build
  - Update reno for stable/pike
  - Remove use of positional decorator
  - Remove setting of version/release from releasenotes
  - Rename deprecated context params
  - Update the documentation link for doc migration
  - Revert "Postpone deprecation warnings to Pike"
  - Ouput a placeholder instead of the auth_token
  - Make from_dict extensible
  - add bandit to pep8 job
  - Output 'project' key in context's to_dict function
  - Updated from global requirements
  - Avoid tox_install.sh for constraints support
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 2.17.0
  - Provide unified calling interface for global_id
  - Fix URLs according to document migration
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Cleanup document formatting
  - rearrange the documentation to fit into the new standard layout
  - Postpone deprecation warnings to Pike
  - [Fix gate]Update test requirement
  - Add global_request_id to context
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - Switch from oslosphinx to openstackdocstheme
  - Optimize the link address
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.12.1:
  - Move existing attributes to _id suffixed attributes
  - Reformat the Context.__init__ arguments
  - Remove references to Python 3.4
  - Add Constraints support
  - Show team and repo badges on README
  - Update .gitreview for stable/ocata
  - Postpone deprecation warnings to Pike
  - Updated from global requirements
  - Add the service token details to context
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 2.11.0:
  - Update reno for stable/newton
  - Revert "Fix X-User and X-Tenant deprecated headers in from_environ"
  - Changed the home-page link
  - Fix typos
  - Enable release notes translation
  - Fix X-User and X-Tenant deprecated headers in from_environ
  - Updated from global requirements
  - Provide a way to deprecate policy values
* Thu Sep  1 2016 tbechtold@suse.com
- update to version 2.9.0
  * Emit deprecation warnings when positional args passed
  * Fix parameters of assertEqual are misplaced
  * Updated from global requirements
  * Manually specify from_dict parameters
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 2.8.0
  * Delete H803 in flake8 ignore list
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 2.7.0
  * Add Python 3.5 classifier and venv
  * Allow deprecated X-Tenant-Name in from_environ
* Fri Jul 29 2016 dmueller@suse.com
- update to 2.6.0:
  * Handle openstack.request_id in from_environ
  * Add is_admin_project to context
  * Updated from global requirements
  * Add reno for releasenotes management
  * Add oslo.context name attributes matching ids
* Mon Jul  4 2016 tbechtold@suse.com
- Update .spec from upstream via renderspec source service
* Tue Jun 14 2016 dmueller@suse.com
- update to 2.4.0:
  * Trivial: ignore openstack/common in flake8 exclude list
  * Strip roles in from_environ
  * Allow deprecated headers in from_environ
  * Drop babel as requirement since its not used
  * Updated from global requirements
  * Ensure to_dict() supports unicode
* Thu Jun  2 2016 tbechtold@suse.com
- use renderspec source service
- update spec from upstream
* Thu Mar  3 2016 tbechtold@suse.com
- Switch to .spec from rpm-packaging upstream project
* Fri Feb 26 2016 dmueller@suse.com
- update to 2.2.0:
  * Standardize an oslo.policy credentials dictionary
  * Revert "Add common oslo.log format parameters"
  * Add roles to context
  * Agnostic approach to construct context from_dict
  * Add common oslo.log format parameters
  * Improve Context docs with example syntax
  * Define method for oslo.log context parameters
  * Add additional unit tests
  * Fix request_id type on Python 3: use text (Unicode)
  * Updated from global requirements
  * Provide a helper to load a context from environment
  * Revert "Add properties for id attributes"
  * Add properties for id attributes
  * Trival: Remove 'MANIFEST.in'
  * Updated from global requirements
  * Remove python 2.6 classifier
  * Remove python 2.6 and cleanup tox.ini
  * Remove reference to undefined attributes
  * Fix coverage configuration and execution
  * Add shields.io version/downloads links/badges into README.rst
  * Change ignore-errors to ignore_errors
  * Updated from global requirements
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.6.0:
  * Updated from global requirements
* Thu Aug 27 2015 tbechtold@suse.com
- update to 0.5.0:
  * Updated from global requirements
  * Add tox target to find missing requirements
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file
- Add -doc package
* Wed Jun  3 2015 dmueller@suse.com
- remove python-hacking dep
* Tue Jun  2 2015 tbechtold@suse.com
- update to 0.4.0:
  * Remove support for Python 3.3
  * Do not sync run_cross_tests.sh
  * Updated from global requirements
  * Uncap library requirements for liberty
  * Standardize setup.cfg summary for oslo libs
  * Update to latest hacking
  * Updated from global requirements
  * fix bug tracker link
- add _service file
* Tue Mar 10 2015 tbechtold@suse.com
- update to 0.2.0:
  * ensure we reset contexts when fixture is used
  * Activate pep8 check that _ is imported
* Wed Jan  7 2015 tbechtold@suse.com
- Initial packaging
